// FBuild - the main application
//------------------------------------------------------------------------------

// Includes
//------------------------------------------------------------------------------
#include "Tools/FBuild/FBuildCore/PrecompiledHeader.h"

#include "FBuildOptions.h"

//#include "FLog.h"
//#include "BFF/BFFParser.h"
//#include "BFF/Functions/Function.h"
//#include "Cache/ICache.h"
//#include "Cache/Cache.h"
//#include "Cache/CachePlugin.h"
//#include "Graph/Node.h"
//#include "Graph/NodeGraph.h"
//#include "Graph/NodeProxy.h"
//#include "Helpers/Report.h"
//#include "Protocol/Client.h"
//#include "Protocol/Protocol.h"
//#include "WorkerPool/JobQueue.h"
//#include "WorkerPool/WorkerThread.h"
//
//#include "Core/Env/Assert.h"
#include "Core/Env/Env.h"
//#include "Core/Env/Types.h"
//#include "Core/FileIO/FileIO.h"
//#include "Core/FileIO/FileStream.h"
//#include "Core/FileIO/MemoryStream.h"
//#include "Core/Process/SystemMutex.h"
//#include "Core/Profile/Profile.h"
//#include "Core/Strings/AStackString.h"
//#include "Core/Tracing/Tracing.h"


// CONSTRUCTOR - FBuildOptions
//------------------------------------------------------------------------------
FBuildOptions::FBuildOptions()
: m_ForceCleanBuild( false )
, m_UseCacheRead( false )
, m_UseCacheWrite( false )
, m_ShowInfo( false )
, m_ShowCommandLines( false )
, m_ShowProgress( false )
, m_ShowErrors( true )
, m_AllowDistributed( false )
, m_ShowSummary( false )
, m_ShowBuildTime( true )
, m_SaveDBOnCompletion( false )
, m_GenerateReport( false )
, m_NoLocalConsumptionOfRemoteJobs( false )
, m_AllowLocalRace( true )
, m_WrapperChild( false )
, m_FixupErrorPaths( false )
, m_StopOnFirstError( true )
{
#ifdef DEBUG
	//m_ShowInfo = true; // uncomment this to enable spam when debugging
#endif

	// Default to NUMBER_OF_PROCESSORS
	m_NumWorkerThreads = Env::GetNumProcessors();
}

// FBuildOptions::SetWorkingDir
//------------------------------------------------------------------------------
void FBuildOptions::SetWorkingDir( const AString & path )
{
	m_WorkingDir = path;
	if ( m_WorkingDir.IsEmpty() )
	{
		return;
	}

	// clean path

	// slashed must face the right way
	m_WorkingDir.Replace( '/', '\\' );

	// eliminate redundant slash pairs
	while ( m_WorkingDir.Replace( "\\\\", "\\" ) );

	// no trailing slash
	if ( m_WorkingDir.EndsWith( '\\' ) )
	{
		m_WorkingDir.SetLength( m_WorkingDir.GetLength() - 1 );
	}

	#if defined( __WINDOWS__ )
		// so C:\ and c:\ are treated the same on Windows, for better cache hits
		// make the drive letter always uppercase
		if ( ( m_WorkingDir.GetLength() >= 2 ) &&
			 ( m_WorkingDir[ 1 ] == ':' ) &&
			 ( m_WorkingDir[ 0 ] >= 'a' ) &&
			 ( m_WorkingDir[ 0 ] <= 'z' ) )
		{
			m_WorkingDir[ 0 ] = ( 'A' + ( m_WorkingDir[ 0 ] - 'a' ) );
		}
	#endif
}

//------------------------------------------------------------------------------
